"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSignature = void 0;
const ts = require("typescript");
const assert = require("assert");
const models_1 = require("../../models");
const converter_events_1 = require("../converter-events");
const convert_expression_1 = require("../convert-expression");
function createSignature(context, kind, signature, declaration) {
    var _a;
    assert(context.scope instanceof models_1.DeclarationReflection);
    // signature.getDeclaration might return undefined.
    // https://github.com/microsoft/TypeScript/issues/30014
    declaration !== null && declaration !== void 0 ? declaration : (declaration = signature.getDeclaration());
    let commentDeclaration = declaration;
    if (commentDeclaration && ts.isArrowFunction(commentDeclaration)) {
        commentDeclaration = commentDeclaration.parent;
    }
    const sigRef = new models_1.SignatureReflection(context.scope.name, kind, context.scope);
    sigRef.typeParameters = convertTypeParameters(context, sigRef, signature.typeParameters, commentDeclaration);
    sigRef.parameters = convertParameters(context, sigRef, signature.parameters, declaration === null || declaration === void 0 ? void 0 : declaration.parameters);
    sigRef.type = context.converter.convertType(context, (_a = declaration === null || declaration === void 0 ? void 0 : declaration.type) !== null && _a !== void 0 ? _a : signature.getReturnType(), declaration);
    context.registerReflection(sigRef, undefined);
    context.trigger(converter_events_1.ConverterEvents.CREATE_SIGNATURE, sigRef, commentDeclaration);
    return sigRef;
}
exports.createSignature = createSignature;
function convertParameters(context, sigRef, parameters, parameterNodes) {
    return parameters.map((param, i) => {
        var _a;
        const declaration = param.valueDeclaration;
        assert(declaration && ts.isParameter(declaration));
        const paramRefl = new models_1.ParameterReflection(/__\d+/.test(param.name) ? "__namedParameters" : param.name, models_1.ReflectionKind.Parameter, sigRef);
        context.registerReflection(paramRefl, param);
        paramRefl.type = context.converter.convertType(context.withScope(paramRefl), (_a = parameterNodes === null || parameterNodes === void 0 ? void 0 : parameterNodes[i].type) !== null && _a !== void 0 ? _a : getTypeOfSymbol(param, context), parameterNodes === null || parameterNodes === void 0 ? void 0 : parameterNodes[i]);
        paramRefl.defaultValue = convert_expression_1.convertDefaultValue(parameterNodes === null || parameterNodes === void 0 ? void 0 : parameterNodes[i]);
        paramRefl.setFlag(models_1.ReflectionFlag.Optional, !!declaration.questionToken);
        paramRefl.setFlag(models_1.ReflectionFlag.Rest, !!declaration.dotDotDotToken);
        return paramRefl;
    });
}
function convertTypeParameters(context, parent, parameters, typeContextNode) {
    return parameters === null || parameters === void 0 ? void 0 : parameters.map((param) => {
        const constraintT = param.getConstraint();
        const defaultT = param.getDefault();
        const constraint = constraintT
            ? context.converter.convertType(context, constraintT, typeContextNode)
            : void 0;
        const defaultType = defaultT
            ? context.converter.convertType(context, defaultT, typeContextNode)
            : void 0;
        const paramRefl = new models_1.TypeParameterReflection(param.symbol.name, constraint, defaultType, parent);
        context.registerReflection(paramRefl, undefined);
        context.trigger(converter_events_1.ConverterEvents.CREATE_TYPE_PARAMETER, paramRefl);
        return paramRefl;
    });
}
function getTypeOfSymbol(symbol, context) {
    var _a;
    const decl = (_a = symbol.getDeclarations()) === null || _a === void 0 ? void 0 : _a[0];
    return decl
        ? context.checker.getTypeOfSymbolAtLocation(symbol, decl)
        : context.checker.getDeclaredTypeOfSymbol(symbol);
}
//# sourceMappingURL=signature.js.map